<?php
/**
 * Plugin Name: SimpleBreadcrumbs
 * Description: Provides list of breadcrumbs for use in themes.
 * Version: 1.0
 * Author: John Stray
 * Author URI: https://www.johnstray.com/get-simple/plugins/simple-breadcrumbs/
 * 
 * This plugin requires that the 'i18n Navigation' plugin be installed for full length breadcrumbs. If this
 * plugin is not installed, it'll use the backup method of 'Home / Parent / Current' only.
 */

# get correct id for plugin
$bcfile=basename(__FILE__, ".php");

# register plugin
register_plugin(
	$bcfile, 								                                            # ID of plugin, should be filename minus php
	'SimpleBreadcrumbs', 	                                              # Title of plugin
	'1.0', 											                                        # Version of plugin
	'John Stray',									                                      # Author of plugin
	'https://www.johnstray.com/get-simple/plugins/simple-breadcrumbs/', # Author URL
	'Provides list of breadcrumbs for use in themes.', 	                # Plugin Description
	'theme', 										                                        # Page type of plugin
	'breadcrumbs_admin'  								                                # Function that displays content
);

# Dummy admin function
function breadcrumbs_admin () {}

# Frontend function
function get_breadcrumbs($slug)
{
  # Get the I18N Navigation Frontend Class
  if (class_exists('I18nNavigationFrontend')) {
    $i18n_data = new I18nNavigationFrontend;
  
    # Create associative array of breadcrumbs
    $breadcrumbs = $i18n_data->getBreadcrumbs($slug);
    
    # Output the 'Home' crumb
    echo '<li><a href="' . get_site_url(FALSE) . '" title="' . get_site_name(false) . '">Home</a></li>';
    
    # Format the breadcrumbs
    foreach ( $breadcrumbs as &$crumb ) {
      $text = $crumb['menu'] ? $crumb['menu'] : $crumb['title'];
      $title = $crumb['title'] ? $crumb['title'] : $crumb['menu'];
      $url = function_exists('find_i18n_url') ? find_i18n_url($crumb['url'],$crumb['parent']) : find_url($crumb['url'],$crumb['parent']);
      
      # Output the breadcrumbs
      if ( $crumb['url'] != 'index' ) {
        if ( $crumb['url'] == $slug ) {
          echo '<li class="active">' . $text . '</li>';
        } else {
          echo '<li><a href="' . $url . '" title="'. strip_quotes($title) . '">' . $text . '</a></li>';
        }
      }
    }
  }
  # I18N plugin not installed. Use backup method.
  else {
    
    # Output the 'Home' crumb
    echo '<li><a href="'.get_site_url(FALSE).'" title="' . get_site_name(false) . '">Home</a></li>';
    
    # Is there a parent that is not 'index'?
    $parent = (string)get_parent(FALSE);
    if ( !empty( $parent ) && $parent != 'index' ) {
      
      # Get info about the parent
      $file = GSDATAPAGESPATH . $parent . '.xml';
      if ( file_exists($file) ) {
        $p = getXML($file);
        $p_title = $p->title;
        $p_slug = $p->slug;
        
        # Ouput the 'Parent' crumb
        echo '<li><a href="' . find_url($parent,'') . '">' . $p_title . '</a></li>';
      }
    }
    
    # Output the 'Current' crumb
    if ( $slug != 'index' ) {
      echo '<li class="active">'.get_page_clean_title(FALSE).'</li>';
    }
  }
}
